Processor.App.Extractor.extractor.BaseExtractor.filter\_soup
============================================================

.. currentmodule:: Processor.App.Extractor.extractor

.. automethod:: BaseExtractor.filter_soup